#
# spec file for package powerman
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           powerman
Version:        2.3.20
Release:        6.1
Url:            https://github.com/chaos/powerman
Source0:        https://github.com/chaos/powerman/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.service
Summary:        Centralized Power Control for Clusters
License:        GPL-2.0+
Group:          Productivity/Clustering/HA
BuildRequires:  curl-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcpd-devel
#BuildRequires:  genders
%{?systemd_requires}

%description
PowerMan is a tool for manipulating remote power control (RPC) devices from a 
central location. Several RPC varieties are supported natively by PowerMan and 
Expect-like configurability simplifies the addition of new devices.

%package -n libpowerman0
Summary:        Libraries for applications using PowerMan
Group:          System/Libraries

%description -n libpowerman0
A shared library for applications using PowerMan.

%package devel
Requires:       libpowerman0 = %{version}
Summary:        Headers and libraries for developing applications using PowerMan
Group:          Development/Libraries/C and C++

%description devel
A header file and static library for developing applications using PowerMan.

%prep
%setup -q

%build
# --with-genders
%configure\
	--disable-static\
	--with-httppower
make %{?jobs:-j%jobs}

%install
make install DESTDIR=$RPM_BUILD_ROOT
rm $RPM_BUILD_ROOT%{_libdir}/*.la
rm -rf %{buildroot}%{_sysconfdir}/init.d
install -Dm 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
mv $RPM_BUILD_ROOT%{_sysconfdir}/powerman/powerman.conf.example $RPM_BUILD_ROOT%{_sysconfdir}/powerman/powerman.conf
# 
rm -r $RPM_BUILD_ROOT%{_libdir}/stonith

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%post -n libpowerman0 -p /sbin/ldconfig

%postun -n libpowerman0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS DISCLAIMER COPYING NEWS README TODO
%{_bindir}/*
%dir %attr(0755,daemon,root) %ghost /run/powerman
%{_mandir}/man?/*.*
%exclude %{_mandir}/man3/*.*
%{_sbindir}/*
%dir %{_sysconfdir}/powerman
%{_unitdir}/%{name}.service
%config %{_sysconfdir}/powerman/powerman.conf
%{_sysconfdir}/powerman/*.dev

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.*

%files -n libpowerman0
%defattr(-,root,root)
%{_libdir}/*.so.*

%changelog
* Thu Mar 12 2015 p.drouand@gmail.com
- Update to version 2.3.20
  * add dist tag to release (TOSS-2667)
  * Minor automake updates
- Move to systemd
- Remove unneeded patchs
  * powerman-piddir.patch
  * powerman-runlevel.patch
- Update project and download Urls; project has moved to github
- Some cleanup
* Mon Aug  4 2014 sfalken@opensuse.org
- Updates in 2.3.16
  * Fix duplicate node name (Issue 35)
    Pulled in another hotlist fix (Mark Grondona)
  * Fix powerman stonith OFF should verify plug state (chaos bz 1439)
- Updated powerman-pidfile.patch to reflect /run instead of /var/run
* Wed Jul 30 2014 sfalken@opensuse.org
- Updated to 2.3.16
  * Changed /var/run to /run in .spec to fix rpmlint check failures
    Updated URL in .spec file
  * Added:
  powerman-2.3.16.tar.gz
  * Removed:
  powerman-2.3.9.tar.bz2
  * Updated:
  powerman.spec
* Thu Dec  8 2011 coolo@suse.com
- the COPYING is GPL-2.0+
* Thu Jul 28 2011 sbrabec@suse.cz
- Update to version 2.3.9:
  * Add MIB support to snmppower.
  * Add eaton-epdu-blue-switched.dev.
  * Add support for SNMP power controllers.
  * Add SNMP dev files for 8-port APC, 8-port Baytech, and 20 port
    Eaton Revelation PDU.
  * Add support for APC 7900 revision 3 firmware.
  * Add support for Appro Greenblade.
  * Add support for APC 7920.
  * Add Support for ranged beacon on/off device scripts, and beacon
    support for ipmipower.
- Make heartbeat support optional as it is dropped now.
* Wed May 19 2010 ro@suse.de
- keep /var/run/powerman only as ghost in filelist
  and create it in initscript if missing
* Tue May 18 2010 aj@suse.de
- Add pkg-config as build requires.
* Fri Aug 14 2009 sbrabec@suse.cz
- PreReq fix.
* Mon Aug 10 2009 sbrabec@suse.cz
- New SuSE package, version 2.3.5.
